@@ -72,8 +72,8 @@ CtrlAgentCfgMgr::createNewContext() {
     return (ConfigPtr(new CtrlAgentCfgContext()));
 }
 
-isc::data::ConstElementPtr
-CtrlAgentCfgMgr::parse(isc::data::ConstElementPtr config_set, bool check_only) {
+ConstElementPtr
+CtrlAgentCfgMgr::parse(ConstElementPtr config_set, bool check_only) {
     // Do a sanity check first.
     if (!config_set) {
         isc_throw(DhcpConfigError, "Mandatory config parameter not provided");
@@ -121,6 +121,65 @@ CtrlAgentCfgMgr::parse(isc::data::ConstElementPtr config_set, bool check_only) {
     return (answer);
 }
 
+ConstElementPtr
+CtrlAgentCfgMgr::redactConfig(ConstElementPtr config) const {
+    bool redacted = false;
+    ConstElementPtr result = redactElement(config, redacted);
+    if (redacted) {
+        return (result);
+    }
+    return (config);
+}
+
+ConstElementPtr
+CtrlAgentCfgMgr::redactElement(ConstElementPtr elem, bool& redacted) const {
+    // From isc::data::copy.
+    if (!elem) {
+        isc_throw(BadValue, "redactElement got a null pointer");
+    }
+    // Redact lists.
+    if (elem->getType() == Element::list) {
+        ElementPtr result = ElementPtr(new ListElement());
+        for (auto item : elem->listValue()) {
+            // add wants a ElementPtr so use a shallow copy.
+            ElementPtr copy = data::copy(redactElement(item, redacted), 0);
+            result->add(copy);
+        }
+        if (redacted) {
+            return (result);
+        }
+        return (elem);
+    }
+    // Redact maps.
+    if (elem->getType() == Element::map) {
+        ElementPtr result = ElementPtr(new MapElement());
+        for (auto kv : elem->mapValue()) {
+            auto key = kv.first;
+            auto value = kv.second;
+
+            if (key == "password") {
+                // Handle passwords.
+                redacted = true;
+                result->set(key, Element::create(std::string("*****")));
+            } else if ((key == "Control-agent") ||
+                       (key == "authentication") ||
+                       (key == "clients")) {
+                // Handle the arc where are passwords.
+                result->set(key, redactElement(value, redacted));
+            } else {
+                // Default case: no password here.
+                result->set(key, value);
+            }
+        }
+        if (redacted) {
+            return (result);
+        }
+        return (elem);
+    }
+    // Handle other element types.
+    return (elem);
+}
+
 data::ConstElementPtr
 CtrlAgentCfgContext::getControlSocketInfo(const std::string& service) const {
     auto si = ctrl_sockets_.find(service);
@@ -128,7 +187,7 @@ CtrlAgentCfgContext::getControlSocketInfo(const std::string& service) const {
 }
 
 void
-CtrlAgentCfgContext::setControlSocketInfo(const isc::data::ConstElementPtr& control_socket,
+CtrlAgentCfgContext::setControlSocketInfo(const ConstElementPtr& control_socket,
                                           const std::string& service) {
     ctrl_sockets_[service] = control_socket;
 }
