@@ -1,9 +1,11 @@
-// Copyright (C) 2015-2017 Internet Systems Consortium, Inc. ("ISC")
+// Copyright (C) 2015-2019 Internet Systems Consortium, Inc. ("ISC")
 //
 // This Source Code Form is subject to the terms of the Mozilla Public
 // License, v. 2.0. If a copy of the MPL was not distributed with this
 // file, You can obtain one at http://mozilla.org/MPL/2.0/.
 
+#include <config.h>
+
 #include <lfc/lfc_controller.h>
 #include <util/csv_file.h>
 #include <gtest/gtest.h>
@@ -82,11 +84,11 @@ protected:
         cstr_ = base_dir + "/" + "config_file";     // config
 
         v4_hdr_ = "address,hwaddr,client_id,valid_lifetime,expire,subnet_id,"
-                  "fqdn_fwd,fqdn_rev,hostname,state\n";
+                  "fqdn_fwd,fqdn_rev,hostname,state,user_context\n";
 
         v6_hdr_ = "address,duid,valid_lifetime,expire,subnet_id,"
                   "pref_lifetime,lease_type,iaid,prefix_len,fqdn_fwd,"
-                  "fqdn_rev,hostname,hwaddr,state\n";
+                  "fqdn_rev,hostname,hwaddr,state,user_context\n";
 
         // and remove any outstanding test files
         removeTestFile();
@@ -396,27 +398,28 @@ TEST_F(LFCControllerTest, launch4) {
     // We have several entries for different leases, the naming is:
     // <lease letter>_<version#>
     string a_1 = "192.0.2.1,06:07:08:09:0a:bc,,"
-                 "200,200,8,1,1,host.example.com,1\n";
+                 "200,200,8,1,1,host.example.com,1,\n";
     string a_2 = "192.0.2.1,06:07:08:09:0a:bc,,"
-                 "200,500,8,1,1,host.example.com,1\n";
+                 "200,500,8,1,1,host.example.com,1,\n";
     string a_3 = "192.0.2.1,06:07:08:09:0a:bc,,"
-                 "200,800,8,1,1,host.example.com,1\n";
+                 "200,800,8,1,1,host.example.com,1,{ \"foo\": true }\n";
 
     string b_1 = "192.0.3.15,dd:de:ba:0d:1b:2e:3e:4f,0a:00:01:04,"
-                 "100,100,7,0,0,,1\n";
+                 "100,100,7,0,0,,1,{ \"bar\": false }\n";
     string b_2 = "192.0.3.15,dd:de:ba:0d:1b:2e:3e:4f,0a:00:01:04,"
-                 "100,135,7,0,0,,1\n";
+                 "100,135,7,0,0,,1,\n";
     string b_3 = "192.0.3.15,dd:de:ba:0d:1b:2e:3e:4f,0a:00:01:04,"
-                 "100,150,7,0,0,,1\n";
+                 "100,150,7,0,0,,1,\n";
 
-    // This one should be invalid, no hardware address and state is not declined
-    string c_1 = "192.0.2.3,,a:11:01:04,"
-                 "200,200,8,1,1,host.example.com,0\n";
+    // This one should be invalid, no hardware address or client id
+    // and state is not declined
+    string c_1 = "192.0.2.3,,,"
+                 "200,200,8,1,1,host.example.com,0,\n";
 
     string d_1 = "192.0.2.5,16:17:18:19:1a:bc,,"
-                 "200,200,8,1,1,host.example.com,1\n";
+                 "200,200,8,1,1,host.example.com,1,\n";
     string d_2 = "192.0.2.5,16:17:18:19:1a:bc,,"
-                 "0,200,8,1,1,host.example.com,1\n";
+                 "0,200,8,1,1,host.example.com,1,\n";
 
     // Subtest 1: both previous and copy available.
     // Create the test previous file
@@ -485,7 +488,7 @@ TEST_F(LFCControllerTest, launch4) {
     // Run the cleanup
     launch(lfc_controller, argc, argv);
 
-    // Compare the results, we expect a header and no leaes.
+    // Compare the results, we expect a header and no leases.
     // We also verify none of the temp or pid files remain.
     test_str = v4_hdr_;
     EXPECT_EQ(readFile(xstr_), test_str);
@@ -551,27 +554,29 @@ TEST_F(LFCControllerTest, launch6) {
     // We have several entries for different leases, the naming is:
     // <lease letter>_<version#>.
     string a_1 = "2001:db8:1::1,00:01:02:03:04:05:06:0a:0b:0c:0d:0e:0f,"
-                 "200,200,8,100,0,7,0,1,1,host.example.com,,1\n";
-    string a_2 = "2001:db8:1::1,,200,200,8,100,0,7,0,1,1,host.example.com,,1\n";
+                 "200,200,8,100,0,7,0,1,1,host.example.com,,1,\n";
+    string a_2 = "2001:db8:1::1,,200,200,8,100,0,7,0,1,1,"
+                 "host.example.com,,1,\n";
     string a_3 = "2001:db8:1::1,00:01:02:03:04:05:06:0a:0b:0c:0d:0e:0f,"
-                 "200,400,8,100,0,7,0,1,1,host.example.com,,1\n";
+                 "200,400,8,100,0,7,0,1,1,host.example.com,,1,\n";
     string a_4 = "2001:db8:1::1,00:01:02:03:04:05:06:0a:0b:0c:0d:0e:0f,"
-                 "0,200,8,100,0,7,0,1,1,host.example.com,,1\n";
+                 "0,200,8,100,0,7,0,1,1,host.example.com,,1,"
+                 "{ \"foo\": true }\n";
 
     string b_1 = "2001:db8:2::10,01:01:01:01:0a:01:02:03:04:05,"
-                 "300,300,6,150,0,8,0,0,0,,,1\n";
+                 "300,300,6,150,0,8,0,0,0,,,1,{ \"bar\": false }\n";
     string b_2 = "2001:db8:2::10,01:01:01:01:0a:01:02:03:04:05,"
-                 "300,800,6,150,0,8,0,0,0,,,1\n";
+                 "300,800,6,150,0,8,0,0,0,,,1,\n";
     string b_3 = "2001:db8:2::10,01:01:01:01:0a:01:02:03:04:05,"
-                 "300,1000,6,150,0,8,0,0,0,,,1\n";
+                 "300,1000,6,150,0,8,0,0,0,,,1,\n";
 
     string c_1 = "3000:1::,00:01:02:03:04:05:06:0a:0b:0c:0d:0e:0f,"
-                 "100,200,8,0,2,16,64,0,0,,,1\n";
+                 "100,200,8,0,2,16,64,0,0,,,1,\n";
     string c_2 = "3000:1::,00:01:02:03:04:05:06:0a:0b:0c:0d:0e:0f,"
-                 "100,400,8,0,2,16,64,0,0,,,1\n";
+                 "100,400,8,0,2,16,64,0,0,,,1,\n";
 
     string d_1 = "2001:db8:1::3,00:01:02:03:04:05:06:0a:0b:0c:0d:0e:0f,"
-                 "200,600,8,100,0,7,0,1,1,host.example.com,,1\n";
+                 "200,600,8,100,0,7,0,1,1,host.example.com,,1,\n";
 
     // Subtest 1: bot previous and copy available
     // Create the test previous file
