@@ -7,6 +7,7 @@
 #ifndef HOST_MGR_H
 #define HOST_MGR_H
 
+#include <asiolink/io_service.h>
 #include <database/database_connection.h>
 #include <dhcpsrv/base_host_data_source.h>
 #include <dhcpsrv/cache_host_data_source.h>
@@ -66,6 +67,7 @@ public:
     ///
     /// @param access Host backend access parameters for the alternate
     /// host backend. It holds "keyword=value" pairs, separated by spaces.
+    ///
     /// The supported values are specific to the alternate backend in use.
     /// However, the "type" parameter will be common and it will specify which
     /// backend is to be used. Currently, no parameters are supported
@@ -78,6 +80,18 @@ public:
     /// @return true when found and removed, false when not found.
     static bool delBackend(const std::string& db_type);
 
+    /// @brief Delete an alternate host backend (aka host data source).
+    ///
+    /// @param db_type database backend type.
+    /// @param access Host backend access parameters for the alternate
+    /// host backend. It holds "keyword=value" pairs, separated by spaces.
+    /// @param if_unusable flag which indicates if the host data source should
+    /// be deleted only if it is unusable.
+    /// @return true when found and removed, false when not found.
+    static bool delBackend(const std::string& db_type,
+                           const std::string& access,
+                           bool if_unusable = false);
+
     /// @brief Delete all alternate backends.
     static void delAllBackends();
 
@@ -617,7 +631,20 @@ public:
         return (ip_reservations_unique_);
     }
 
+    /// @brief Sets IO service to be used by the Host Manager.
+    ///
+    /// @param IOService object, used for all ASIO operations.
+    static void setIOService(const isc::asiolink::IOServicePtr& io_service) {
+        io_service_ = io_service;
+    }
+
+    /// @brief Returns pointer to the IO service.
+    static isc::asiolink::IOServicePtr& getIOService() {
+        return (io_service_);
+    }
+
 protected:
+
     /// @brief The negative caching flag.
     ///
     /// When true and the first backend is a cache
@@ -674,8 +701,11 @@ private:
     /// @c HostMgr.
     static boost::scoped_ptr<HostMgr>& getHostMgrPtr();
 
+    /// The IOService object, used for all ASIO operations.
+    static isc::asiolink::IOServicePtr io_service_;
 };
-}
-}
+
+}  // namespace dhcp
+}  // namespace isc
 
 #endif // HOST_MGR_H
