@@ -25,6 +25,12 @@
 #include <functional>
 #include <string>
 
+/// @brief Template to ignore unused arguments.
+namespace {
+template <typename... Args>
+inline void unused(Args const& ...) {}
+} // end of anonymous namespace
+
 namespace isc {
 namespace dhcp {
 
@@ -333,7 +339,8 @@ public:
     /// @param inheritance inheritance mode to be used.
     Triplet<uint32_t> getValid(const Inheritance& inheritance = Inheritance::ALL) const {
         return (getProperty<Network>(&Network::getValid, valid_, inheritance,
-                                     "valid-lifetime"));
+                                     "valid-lifetime", "min-valid-lifetime",
+                                     "max-valid-lifetime"));
     }
 
     /// @brief Sets new valid lifetime for a network.
@@ -764,12 +771,19 @@ protected:
     /// no global value is found.
     /// @param global_name Name of the global parameter which value should
     /// be returned
+    /// @param min_name Name of the min global parameter which value should
+    /// be returned for triplets
+    /// @param max_name Name of the max global parameter which value should
+    /// be returned for triplets
     ///
     /// @return Optional value fetched from the global level or the value
     /// of @c property.
     template<typename ReturnType>
     ReturnType getGlobalProperty(ReturnType property,
-                                 const std::string& global_name) const {
+                                 const std::string& global_name,
+                                 const std::string& min_name = "",
+                                 const std::string& max_name = "") const {
+        unused(min_name, max_name);
         if (!global_name.empty() && fetch_globals_fn_) {
             data::ConstElementPtr globals = fetch_globals_fn_();
             if (globals && (globals->getType() == data::Element::map)) {
@@ -784,6 +798,57 @@ protected:
         return (property);
     }
 
+    /// @brief The @c getGlobalProperty specialization for Triplet<T>.
+    ///
+    /// @note: use overloading vs specialization because full specialization
+    /// is not allowed in this scope.
+    ///
+    /// @tparam NumType Type of the encapsulated value(s).
+    ///
+    /// @param property Value to be returned when it is specified or when
+    /// no global value is found.
+    /// @param global_name Name of the global parameter which value should
+    /// be returned
+    /// @param min_name Name of the min global parameter which value should
+    /// be returned for triplets
+    /// @param max_name Name of the max global parameter which value should
+    /// be returned for triplets
+    ///
+    /// @return Optional value fetched from the global level or the value
+    /// of @c property.
+    template<typename NumType>
+    Triplet<NumType> getGlobalProperty(Triplet<NumType> property,
+                                       const std::string& global_name,
+                                       const std::string& min_name = "",
+                                       const std::string& max_name = "") const {
+
+        if (!global_name.empty() && fetch_globals_fn_) {
+            data::ConstElementPtr globals = fetch_globals_fn_();
+            if (globals && (globals->getType() == data::Element::map)) {
+                data::ConstElementPtr param = globals->get(global_name);
+                if (param) {
+                    NumType def_value = static_cast<NumType>(param->intValue());
+                    if (min_name.empty() || max_name.empty()) {
+                        return (def_value);
+                    } else {
+                        NumType min_value = def_value;
+                        NumType max_value = def_value;
+                        data::ConstElementPtr min_param = globals->get(min_name);
+                        if (min_param) {
+                            min_value = static_cast<NumType>(min_param->intValue());
+                        }
+                        data::ConstElementPtr max_param = globals->get(max_name);
+                        if (max_param) {
+                            max_value = static_cast<NumType>(max_param->intValue());
+                        }
+                        return (Triplet<NumType>(min_value, def_value, max_value));
+                    }
+                }
+            }
+        }
+        return (property);
+    }
+
     /// @brief The @c getGlobalProperty specialization for Optional<IOAddress>.
     ///
     /// This does two things:
@@ -797,12 +862,18 @@ protected:
     /// no global value is found.
     /// @param global_name Name of the global parameter which value should
     /// be returned
+    /// @param min_name Name of the min global parameter which value should
+    /// be returned for triplets
+    /// @param max_name Name of the max global parameter which value should
+    /// be returned for triplets
     ///
     /// @return Optional value fetched from the global level or the value
     /// of @c property.
     util::Optional<asiolink::IOAddress>
     getGlobalProperty(util::Optional<asiolink::IOAddress> property,
-                      const std::string& global_name) const;
+                      const std::string& global_name,
+                      const std::string& min_name = "",
+                      const std::string& max_name = "") const;
 
     /// @brief Returns a value associated with a network using inheritance.
     ///
@@ -827,6 +898,10 @@ protected:
     /// level. This value is empty by default, which indicates that the
     /// global value for the given parameter is not supported and shouldn't
     /// be fetched.
+    /// @param min_name Name of the min global parameter which value should
+    /// be returned for triplets
+    /// @param max_name Name of the max global parameter which value should
+    /// be returned for triplets
     ///
     /// @return Optional value fetched from this instance level, parent
     /// network level or global level
@@ -834,7 +909,9 @@ protected:
     ReturnType getProperty(ReturnType(BaseType::*MethodPointer)(const Inheritance&) const,
                            ReturnType property,
                            const Inheritance& inheritance,
-                           const std::string& global_name = "") const {
+                           const std::string& global_name = "",
+                           const std::string& min_name = "",
+                           const std::string& max_name = "") const {
 
         // If no inheritance is to be used, return the value for this
         // network regardless if it is specified or not.
@@ -853,7 +930,7 @@ protected:
 
         // If global value requested, return it.
         } else if (inheritance == Inheritance::GLOBAL) {
-            return (getGlobalProperty(ReturnType(), global_name));
+            return (getGlobalProperty(ReturnType(), global_name, min_name, max_name));
         }
 
         // We use inheritance and the value is not specified on the network level.
@@ -876,7 +953,7 @@ protected:
             // can be specified on global level and there is a callback
             // that returns the global values, try to find this parameter
             // at the global scope.
-            return (getGlobalProperty(property, global_name));
+            return (getGlobalProperty(property, global_name, min_name, max_name));
         }
 
         // We haven't found the value at any level, so return the unspecified.
@@ -1202,7 +1279,9 @@ public:
     Triplet<uint32_t>
     getPreferred(const Inheritance& inheritance = Inheritance::ALL) const {
         return (getProperty<Network6>(&Network6::getPreferred, preferred_,
-                                      inheritance, "preferred-lifetime"));
+                                      inheritance, "preferred-lifetime",
+                                      "min-preferred-lifetime",
+                                      "max-preferred-lifetime"));
     }
 
     /// @brief Sets new preferred lifetime for a network.
