@@ -328,7 +328,7 @@ RelayInfoParser::parse(const isc::dhcp::Network::RelayInfoPtr& relay_info,
 
     if (addresses->getType() != Element::list) {
         isc_throw(DhcpConfigError, "ip-addresses must be a list "
-                  << " (" << getPosition("ip-addresses", relay_elem) << ")");
+                  "(" << getPosition("ip-addresses", relay_elem) << ")");
     }
 
     BOOST_FOREACH(ConstElementPtr address_element, addresses->listValue()) {
@@ -743,9 +743,15 @@ Subnet4ConfigParser::initSubnet(data::ConstElementPtr params,
                                    subnet_id));
     subnet_ = subnet4;
 
+    // Move from reservation mode to new reservations flags.
+    ElementPtr mutable_params;
+    mutable_params = boost::const_pointer_cast<Element>(params);
+    // @todo add warning
+    BaseNetworkParser::moveReservationMode(mutable_params);
+
     // Parse parameters common to all Network derivations.
     NetworkPtr network = boost::dynamic_pointer_cast<Network>(subnet4);
-    parseCommon(params, network);
+    parseCommon(mutable_params, network);
 
     std::ostringstream output;
     output << addr << "/" << static_cast<int>(len) << " with params: ";
@@ -859,9 +865,6 @@ Subnet4ConfigParser::initSubnet(data::ConstElementPtr params,
         }
     }
 
-    // Let's set host reservation mode.
-    parseHostReservationMode(params, network);
-
     // Try setting up client class.
     if (params->contains("client-class")) {
         string client_class = getString(params, "client-class");
@@ -1237,9 +1240,15 @@ Subnet6ConfigParser::initSubnet(data::ConstElementPtr params,
                                    subnet_id);
     subnet_.reset(subnet6);
 
+    // Move from reservation mode to new reservations flags.
+    ElementPtr mutable_params;
+    mutable_params = boost::const_pointer_cast<Element>(params);
+    // @todo add warning
+    BaseNetworkParser::moveReservationMode(mutable_params);
+
     // Parse parameters common to all Network derivations.
     NetworkPtr network = boost::dynamic_pointer_cast<Network>(subnet_);
-    parseCommon(params, network);
+    parseCommon(mutable_params, network);
 
     // Enable or disable Rapid Commit option support for the subnet.
     if (!rapid_commit.unspecified()) {
@@ -1330,10 +1339,6 @@ Subnet6ConfigParser::initSubnet(data::ConstElementPtr params,
         subnet6->setIface(iface);
     }
 
-    // Let's set host reservation mode. If not specified, the default value of
-    // all will be used.
-    parseHostReservationMode(params, network);
-
     // Try setting up client class.
     if (params->contains("client-class")) {
         string client_class = getString(params, "client-class");
