@@ -7,6 +7,7 @@
 #ifndef PGSQL_LEASE_MGR_H
 #define PGSQL_LEASE_MGR_H
 
+#include <asiolink/io_service.h>
 #include <dhcp/hwaddr.h>
 #include <dhcpsrv/dhcpsrv_exceptions.h>
 #include <dhcpsrv/lease_mgr.h>
@@ -42,7 +43,11 @@ public:
     /// @brief Constructor
     ///
     /// @param parameters See PgSqlLeaseMgr constructor.
-    PgSqlLeaseContext(const db::DatabaseConnection::ParameterMap& parameters);
+    /// @param io_service The IOService object, used for all ASIO operations.
+    /// @param db_reconnect_callback The connection recovery callback.
+    PgSqlLeaseContext(const db::DatabaseConnection::ParameterMap& parameters,
+                      const isc::asiolink::IOServicePtr& io_service,
+                      db::DbCallback db_reconnect_callback);
 
     /// The exchange objects are used for transfer of data to/from the database.
     /// They are pointed-to objects as the contents may change in "const" calls,
@@ -120,6 +125,30 @@ public:
     /// failed.
     PgSqlLeaseContextPtr createContext() const;
 
+    /// @brief Attempts to reconnect the server to the lease DB backend manager.
+    ///
+    /// This is a self-rescheduling function that attempts to reconnect to the
+    /// server's lease DB backends after connectivity to one or more have been
+    /// lost. Upon entry it will attempt to reconnect via
+    /// @ref LeaseMgrFactory::create.
+    /// If this is successful, DHCP servicing is re-enabled and server returns
+    /// to normal operation.
+    ///
+    /// If reconnection fails and the maximum number of retries has not been
+    /// exhausted, it will schedule a call to itself to occur at the
+    /// configured retry interval. DHCP service remains disabled.
+    ///
+    /// If the maximum number of retries has been exhausted an error is logged
+    /// and the server shuts down.
+    ///
+    /// This function is passed to the connection recovery mechanism. It will be
+    /// invoked when a connection loss is detected.
+    ///
+    /// @param db_reconnect_ctl pointer to the ReconnectCtl containing the
+    /// configured reconnect parameters.
+    /// @return true if connection has been recovered, false otherwise.
+    static bool dbReconnect(db::ReconnectCtlPtr db_reconnect_ctl);
+
     /// @brief Local version of getDBVersion() class method
     static std::string getDBVersion();
 
@@ -428,6 +457,15 @@ public:
     ///        exist.
     /// @throw isc::db::DbOperationError An operation on the open database has
     ///        failed.
+    ///
+    /// @note The current_cltt_ and current_valid_lft_ are used to maximize the
+    /// chance that only one thread or process performs an update or delete
+    /// operation on the lease by matching these values with the expiration time
+    /// data in the database.
+    /// @note The UPDATE query uses WHERE expire = ? to update the lease only if
+    /// the value matches the one received on the SELECT query, effectively
+    /// enforcing no update on the lease between SELECT and UPDATE with
+    /// different expiration time.
     virtual void updateLease4(const Lease4Ptr& lease4);
 
     /// @brief Updates IPv6 lease.
@@ -441,6 +479,15 @@ public:
     ///        exist.
     /// @throw isc::db::DbOperationError An operation on the open database has
     ///        failed.
+    ///
+    /// @note The current_cltt_ and current_valid_lft_ are used to maximize the
+    /// chance that only one thread or process performs an update or delete
+    /// operation on the lease by matching these values with the expiration time
+    /// data in the database.
+    /// @note The UPDATE query uses WHERE expire = ? to update the lease only if
+    /// the value matches the one received on the SELECT query, effectively
+    /// enforcing no update on the lease between SELECT and UPDATE with
+    /// different expiration time.
     virtual void updateLease6(const Lease6Ptr& lease6);
 
     /// @brief Deletes an IPv4 lease.
@@ -448,6 +495,15 @@ public:
     /// @param lease IPv4 lease being deleted.
     ///
     /// @return true if deletion was successful, false if no such lease exists.
+    ///
+    /// @note The current_cltt_ and current_valid_lft_ are used to maximize the
+    /// chance that only one thread or process performs an update or delete
+    /// operation on the lease by matching these values with the expiration time
+    /// data in the database.
+    /// @note The DELETE query uses WHERE expire = ? to delete the lease only if
+    /// the value matches the one received on the SELECT query, effectively
+    /// enforcing no update on the lease between SELECT and DELETE with
+    /// different expiration time.
     virtual bool deleteLease(const Lease4Ptr& lease);
 
     /// @brief Deletes an IPv6 lease.
@@ -455,6 +511,15 @@ public:
     /// @param lease IPv6 lease being deleted.
     ///
     /// @return true if deletion was successful, false if no such lease exists.
+    ///
+    /// @note The current_cltt_ and current_valid_lft_ are used to maximize the
+    /// chance that only one thread or process performs an update or delete
+    /// operation on the lease by matching these values with the expiration time
+    /// data in the database.
+    /// @note The DELETE query uses WHERE expire = ? to delete the lease only if
+    /// the value matches the one received on the SELECT query, effectively
+    /// enforcing no update on the lease between SELECT and DELETE with
+    /// different expiration time.
     virtual bool deleteLease(const Lease6Ptr& lease);
 
     /// @brief Deletes all expired-reclaimed DHCPv4 leases.
@@ -668,8 +733,9 @@ private:
     ///
     /// @throw isc::db::DbOperationError An operation on the open database has
     ///        failed.
-    bool addLeaseCommon(PgSqlLeaseContextPtr ctx,
-                        StatementIndex stindex, db::PsqlBindArray& bind_array);
+    bool addLeaseCommon(PgSqlLeaseContextPtr& ctx,
+                        StatementIndex stindex,
+                        db::PsqlBindArray& bind_array);
 
     /// @brief Get Lease Collection Common Code
     ///
@@ -693,7 +759,7 @@ private:
     /// @throw isc::db::MultipleRecords Multiple records were retrieved
     ///        from the database where only one was expected.
     template <typename Exchange, typename LeaseCollection>
-    void getLeaseCollection(PgSqlLeaseContextPtr ctx,
+    void getLeaseCollection(PgSqlLeaseContextPtr& ctx,
                             StatementIndex stindex,
                             db::PsqlBindArray& bind_array,
                             Exchange& exchange, LeaseCollection& result,
@@ -716,7 +782,7 @@ private:
     ///        failed.
     /// @throw isc::db::MultipleRecords Multiple records were retrieved
     ///        from the database where only one was expected.
-    void getLeaseCollection(PgSqlLeaseContextPtr ctx,
+    void getLeaseCollection(PgSqlLeaseContextPtr& ctx,
                             StatementIndex stindex,
                             db::PsqlBindArray& bind_array,
                             Lease4Collection& result) const {
@@ -739,7 +805,7 @@ private:
     ///        failed.
     /// @throw isc::db::MultipleRecords Multiple records were retrieved
     ///        from the database where only one was expected.
-    void getLeaseCollection(PgSqlLeaseContextPtr ctx,
+    void getLeaseCollection(PgSqlLeaseContextPtr& ctx,
                             StatementIndex stindex,
                             db::PsqlBindArray& bind_array,
                             Lease6Collection& result) const {
@@ -756,7 +822,7 @@ private:
     /// @param stindex Index of statement being executed
     /// @param bind_array array for input parameters
     /// @param result Lease4 object returned
-    void getLease(PgSqlLeaseContextPtr ctx,
+    void getLease(PgSqlLeaseContextPtr& ctx,
                   StatementIndex stindex,
                   db::PsqlBindArray& bind_array,
                   Lease4Ptr& result) const;
@@ -771,7 +837,7 @@ private:
     /// @param stindex Index of statement being executed
     /// @param bind_array array for input parameters
     /// @param result Lease6 object returned
-    void getLease(PgSqlLeaseContextPtr ctx,
+    void getLease(PgSqlLeaseContextPtr& ctx,
                   StatementIndex stindex,
                   db::PsqlBindArray& bind_array,
                   Lease6Ptr& result) const;
@@ -812,7 +878,7 @@ private:
     /// @throw isc::db::DbOperationError An operation on the open database has
     ///        failed.
     template <typename LeasePtr>
-    void updateLeaseCommon(PgSqlLeaseContextPtr ctx,
+    void updateLeaseCommon(PgSqlLeaseContextPtr& ctx,
                            StatementIndex stindex,
                            db::PsqlBindArray& bind_array,
                            const LeasePtr& lease);
@@ -881,6 +947,9 @@ private:
 
     /// @brief The pool of contexts
     PgSqlLeaseContextPoolPtr pool_;
+
+    /// @brief Timer name used to register database reconnect timer.
+    std::string timer_name_;
 };
 
 }  // namespace dhcp
