@@ -248,7 +248,7 @@ SrvConfig::mergeGlobals(SrvConfig& other) {
             }
         } catch(const std::exception& ex) {
             isc_throw (BadValue, "Invalid value:" << element->str()
-                       << " explict global:" << name);
+                       << " explicit global:" << name);
         }
     }
 }
@@ -400,6 +400,195 @@ SrvConfig::extractConfiguredGlobals(isc::data::ConstElementPtr config) {
     }
 }
 
+void
+SrvConfig::sanityChecksLifetime(const std::string& name) const {
+    // Initialize as some compilers complain otherwise.
+    uint32_t value = 0;
+    ConstElementPtr has_value = getConfiguredGlobal(name);
+    if (has_value) {
+        value = has_value->intValue();
+    }
+
+    uint32_t min_value = 0;
+    ConstElementPtr has_min = getConfiguredGlobal("min-" + name);
+    if (has_min) {
+        min_value = has_min->intValue();
+    }
+
+    uint32_t max_value = 0;
+    ConstElementPtr has_max = getConfiguredGlobal("max-" + name);
+    if (has_max) {
+        max_value = has_max->intValue();
+    }
+
+    if (!has_value && !has_min && !has_max) {
+        return;
+    }
+    if (has_value) {
+        if (!has_min && !has_max) {
+            // default only.
+            return;
+        } else if (!has_min) {
+            // default and max.
+            min_value = value;
+        } else if (!has_max) {
+            // default and min.
+            max_value = value;
+        }
+    } else if (has_min) {
+        if (!has_max) {
+            // min only.
+            return;
+        } else {
+            // min and max.
+            isc_throw(BadValue, "have min-" << name << " and max-"
+                      << name << " but no " << name << " (default)");
+        }
+    } else {
+        // max only.
+        return;
+    }
+
+    // Check that min <= max.
+    if (min_value > max_value) {
+        if (has_min && has_max) {
+            isc_throw(BadValue, "the value of min-" << name << " ("
+                      << min_value << ") is not less than max-" << name << " ("
+                      << max_value << ")");
+        } else if (has_min) {
+            // Only min and default so min > default.
+            isc_throw(BadValue, "the value of min-" << name << " ("
+                      << min_value << ") is not less than (default) " << name
+                      << " (" << value << ")");
+        } else {
+            // Only default and max so default > max.
+            isc_throw(BadValue, "the value of (default) " << name
+                      << " (" << value << ") is not less than max-" << name
+                      << " (" << max_value << ")");
+        }
+    }
+
+    // Check that value is between min and max.
+    if ((value < min_value) || (value > max_value)) {
+        isc_throw(BadValue, "the value of (default) " << name << " ("
+                  << value << ") is not between min-" << name << " ("
+                  << min_value << ") and max-" << name << " ("
+                  << max_value << ")");
+    }
+}
+
+void
+SrvConfig::sanityChecksLifetime(const SrvConfig& target_config,
+                                const std::string& name) const {
+    // Three cases:
+    //  - the external/source config has the parameter: use it.
+    //  - only the target config has the parameter: use this one.
+    //  - no config has the parameter.
+    uint32_t value = 0;
+    ConstElementPtr has_value = getConfiguredGlobal(name);
+    bool new_value = true;
+    if (!has_value) {
+        has_value = target_config.getConfiguredGlobal(name);
+        new_value = false;
+    }
+    if (has_value) {
+        value = has_value->intValue();
+    }
+
+    uint32_t min_value = 0;
+    ConstElementPtr has_min = getConfiguredGlobal("min-" + name);
+    bool new_min = true;
+    if (!has_min) {
+        has_min = target_config.getConfiguredGlobal("min-" + name);
+        new_min = false;
+    }
+    if (has_min) {
+        min_value = has_min->intValue();
+    }
+
+    uint32_t max_value = 0;
+    ConstElementPtr has_max = getConfiguredGlobal("max-" + name);
+    bool new_max = true;
+    if (!has_max) {
+        has_max = target_config.getConfiguredGlobal("max-" + name);
+        new_max = false;
+    }
+    if (has_max) {
+        max_value = has_max->intValue();
+    }
+
+    if (!has_value && !has_min && !has_max) {
+        return;
+    }
+    if (has_value) {
+        if (!has_min && !has_max) {
+            // default only.
+            return;
+        } else if (!has_min) {
+            // default and max.
+            min_value = value;
+        } else if (!has_max) {
+            // default and min.
+            max_value = value;
+        }
+    } else if (has_min) {
+        if (!has_max) {
+            // min only.
+            return;
+        } else {
+            // min and max.
+            isc_throw(BadValue, "have min-" << name << " and max-"
+                      << name << " but no " << name << " (default)");
+        }
+    } else {
+        // max only.
+        return;
+    }
+
+    // Check that min <= max.
+    if (min_value > max_value) {
+        if (has_min && has_max) {
+            std::string from_min = (new_min ? "new" : "previous");
+            std::string from_max = (new_max ? "new" : "previous");
+            isc_throw(BadValue, "the value of " << from_min
+                      << " min-" << name << " ("
+                      << min_value << ") is not less than "
+                      << from_max << " max-" << name
+                      << " (" << max_value << ")");
+        } else if (has_min) {
+            // Only min and default so min > default.
+            std::string from_min = (new_min ? "new" : "previous");
+            std::string from_value = (new_value ? "new" : "previous");
+            isc_throw(BadValue, "the value of " << from_min
+                      << " min-" << name << " ("
+                      << min_value << ") is not less than " << from_value
+                      << " (default) " << name
+                      << " (" << value << ")");
+        } else {
+            // Only default and max so default > max.
+            std::string from_max = (new_max ? "new" : "previous");
+            std::string from_value = (new_value ? "new" : "previous");
+            isc_throw(BadValue, "the value of " << from_value
+                      << " (default) " << name
+                      << " (" << value << ") is not less than " << from_max
+                      << " max-" << name << " (" << max_value << ")");
+        }
+    }
+
+    // Check that value is between min and max.
+    if ((value < min_value) || (value > max_value)) {
+        std::string from_value = (new_value ? "new" : "previous");
+        std::string from_min = (new_min ? "new" : "previous");
+        std::string from_max = (new_max ? "new" : "previous");
+        isc_throw(BadValue, "the value of " << from_value
+                  <<" (default) " << name << " ("
+                  << value << ") is not between " << from_min
+                  << " min-" << name << " (" << min_value
+                  << ") and " << from_max << " max-"
+                  << name << " (" << max_value << ")");
+    }
+}
+
 ElementPtr
 SrvConfig::toElement() const {
     // Toplevel map
