@@ -18,7 +18,7 @@
 #include <hooks/callout_handle.h>
 #include <stats/stats_mgr.h>
 
-#include <dhcpsrv/tests/test_utils.h>
+#include <dhcpsrv/testutils/test_utils.h>
 #include <dhcpsrv/tests/alloc_engine_utils.h>
 
 #include <hooks/hooks_manager.h>
