@@ -11,6 +11,7 @@
 #include <dhcpsrv/srv_config.h>
 #include <dhcpsrv/subnet.h>
 #include <process/logging_info.h>
+#include <testutils/gtest_utils.h>
 #include <testutils/test_to_element.h>
 
 #include <gtest/gtest.h>
@@ -1396,18 +1397,18 @@ TEST_F(SrvConfigTest, getDdnsParamsTest4) {
     // Enable D2Client.
     enableD2Client(true);
 
-    // Make sure subnet1 udpates are still disabled.
+    // Make sure subnet1 updates are still disabled.
     ASSERT_NO_THROW(params = conf_.getDdnsParams(subnet1));
     EXPECT_FALSE(params->getEnableUpdates());
 
-    // Make sure subnet2 udpates are now enabled.
+    // Make sure subnet2 updates are now enabled.
     ASSERT_NO_THROW(params = conf_.getDdnsParams(subnet2));
     EXPECT_TRUE(params->getEnableUpdates());
 
     // Enable sending updates globally.  This should inherit down subnet1.
     conf.addConfiguredGlobal("ddns-send-updates", Element::create(true));
 
-    // Make sure subnet1 udpates are now enabled.
+    // Make sure subnet1 updates are now enabled.
     ASSERT_NO_THROW(params = conf_.getDdnsParams(subnet1));
     EXPECT_TRUE(params->getEnableUpdates());
 }
@@ -1556,18 +1557,18 @@ TEST_F(SrvConfigTest, getDdnsParamsTest6) {
     // Enable D2Client.
     enableD2Client(true);
 
-    // Make sure subnet1 udpates are still disabled.
+    // Make sure subnet1 updates are still disabled.
     ASSERT_NO_THROW(params = conf_.getDdnsParams(subnet1));
     EXPECT_FALSE(params->getEnableUpdates());
 
-    // Make sure subnet2 udpates are now enabled.
+    // Make sure subnet2 updates are now enabled.
     ASSERT_NO_THROW(params = conf_.getDdnsParams(subnet2));
     EXPECT_TRUE(params->getEnableUpdates());
 
     // Enable sending updates globally.  This should inherit down subnet1.
     conf.addConfiguredGlobal("ddns-send-updates", Element::create(true));
 
-    // Make sure subnet1 udpates are now enabled.
+    // Make sure subnet1 updates are now enabled.
     ASSERT_NO_THROW(params = conf_.getDdnsParams(subnet1));
     EXPECT_TRUE(params->getEnableUpdates());
 }
@@ -1620,4 +1621,360 @@ TEST_F(SrvConfigTest, multiThreadingSettings) {
     EXPECT_TRUE(isEquivalent(param, conf.getDHCPMultiThreading()));
 }
 
+// Verifies that sanityChecksLifetime works as expected.
+TEST_F(SrvConfigTest, sanityChecksLifetime) {
+    // First the overload checking the current config.
+    // Note that lifetimes have a default so some cases here should not happen.
+    {
+        SCOPED_TRACE("no lifetime");
+
+        SrvConfig conf(32);
+        EXPECT_NO_THROW(conf.sanityChecksLifetime("lifetime"));
+    }
+
+    {
+        SCOPED_TRACE("lifetime only");
+
+        SrvConfig conf(32);
+        conf.addConfiguredGlobal("lifetime", Element::create(1000));
+        EXPECT_NO_THROW(conf.sanityChecksLifetime("lifetime"));
+    }
+
+    {
+        SCOPED_TRACE("min-lifetime only");
+
+        SrvConfig conf(32);
+        conf.addConfiguredGlobal("min-lifetime", Element::create(1000));
+        EXPECT_NO_THROW(conf.sanityChecksLifetime("lifetime"));
+    }
+
+    {
+        SCOPED_TRACE("max-lifetime only");
+
+        SrvConfig conf(32);
+        conf.addConfiguredGlobal("max-lifetime", Element::create(1000));
+        EXPECT_NO_THROW(conf.sanityChecksLifetime("lifetime"));
+    }
+
+    {
+        SCOPED_TRACE("min-lifetime and max-lifetime but no lifetime");
+
+        SrvConfig conf(32);
+        conf.addConfiguredGlobal("min-lifetime", Element::create(1000));
+        conf.addConfiguredGlobal("max-lifetime", Element::create(2000));
+        std::string msg = "have min-lifetime and max-lifetime but no ";
+        msg += "lifetime (default)";
+        EXPECT_THROW_MSG(conf.sanityChecksLifetime("lifetime"),
+                         isc::BadValue, msg);
+    }
+
+    {
+        SCOPED_TRACE("all lifetime parameters");
+
+        SrvConfig conf(32);
+        conf.addConfiguredGlobal("min-lifetime", Element::create(1000));
+        conf.addConfiguredGlobal("lifetime", Element::create(2000));
+        conf.addConfiguredGlobal("max-lifetime", Element::create(3000));
+        EXPECT_NO_THROW(conf.sanityChecksLifetime("lifetime"));
+    }
+
+    {
+        SCOPED_TRACE("min-lifetime > max-lifetime");
+
+        SrvConfig conf(32);
+        conf.addConfiguredGlobal("min-lifetime", Element::create(2000));
+        conf.addConfiguredGlobal("lifetime", Element::create(2000));
+        conf.addConfiguredGlobal("max-lifetime", Element::create(1000));
+        std::string msg = "the value of min-lifetime (2000) is not less ";
+        msg += "than max-lifetime (1000)";
+        EXPECT_THROW_MSG(conf.sanityChecksLifetime("lifetime"),
+                         isc::BadValue, msg);
+    }
+
+    {
+        SCOPED_TRACE("min-lifetime > lifetime");
+
+        SrvConfig conf(32);
+        conf.addConfiguredGlobal("min-lifetime", Element::create(2000));
+        conf.addConfiguredGlobal("lifetime", Element::create(1000));
+        std::string msg = "the value of min-lifetime (2000) is not less ";
+        msg += "than (default) lifetime (1000)";
+        EXPECT_THROW_MSG(conf.sanityChecksLifetime("lifetime"),
+                         isc::BadValue, msg);
+    }
+
+    {
+        SCOPED_TRACE("lifetime > max-lifetime");
+
+        SrvConfig conf(32);
+        conf.addConfiguredGlobal("lifetime", Element::create(2000));
+        conf.addConfiguredGlobal("max-lifetime", Element::create(1000));
+        std::string msg = "the value of (default) lifetime (2000) is not ";
+        msg += "less than max-lifetime (1000)";
+        EXPECT_THROW_MSG(conf.sanityChecksLifetime("lifetime"),
+                         isc::BadValue, msg);
+    }
+
+    {
+        SCOPED_TRACE("lifetime not between min-lifetime and max-lifetime (too small)");
+
+        SrvConfig conf(32);
+        conf.addConfiguredGlobal("min-lifetime", Element::create(1000));
+        conf.addConfiguredGlobal("lifetime", Element::create(500));
+        conf.addConfiguredGlobal("max-lifetime", Element::create(2000));
+        std::string msg = "the value of (default) lifetime (500) is not ";
+        msg += "between min-lifetime (1000) and max-lifetime (2000)";
+        EXPECT_THROW_MSG(conf.sanityChecksLifetime("lifetime"),
+                         isc::BadValue, msg);
+    }
+
+    {
+        SCOPED_TRACE("lifetime not between min-lifetime and max-lifetime (too large)");
+
+        SrvConfig conf(32);
+        conf.addConfiguredGlobal("min-lifetime", Element::create(1000));
+        conf.addConfiguredGlobal("lifetime", Element::create(3000));
+        conf.addConfiguredGlobal("max-lifetime", Element::create(2000));
+        std::string msg = "the value of (default) lifetime (3000) is not ";
+        msg += "between min-lifetime (1000) and max-lifetime (2000)";
+        EXPECT_THROW_MSG(conf.sanityChecksLifetime("lifetime"),
+                         isc::BadValue, msg);
+    }
+
+    // Second the overload checking an external config before merging.
+    // We assume that the target config is correct as this was the case
+    // when this overload is used, and this lowers the number of cases...
+
+    SrvConfig target(10);
+    target.addConfiguredGlobal("min-lifetime", Element::create(1000));
+    target.addConfiguredGlobal("lifetime", Element::create(2000));
+    target.addConfiguredGlobal("max-lifetime", Element::create(3000));
+
+    {
+        SCOPED_TRACE("no lifetime");
+
+        SrvConfig conf(32);
+        EXPECT_NO_THROW(conf.sanityChecksLifetime(target, "lifetime"));
+    }
+
+    {
+        SCOPED_TRACE("lifetime only");
+
+        SrvConfig conf(32);
+        conf.addConfiguredGlobal("lifetime", Element::create(1000));
+        EXPECT_NO_THROW(conf.sanityChecksLifetime(target, "lifetime"));
+    }
+
+    {
+        SCOPED_TRACE("min-lifetime only");
+
+        SrvConfig conf(32);
+        conf.addConfiguredGlobal("min-lifetime", Element::create(1000));
+        EXPECT_NO_THROW(conf.sanityChecksLifetime(target, "lifetime"));
+    }
+
+    {
+        SCOPED_TRACE("max-lifetime only");
+
+        SrvConfig conf(32);
+        conf.addConfiguredGlobal("max-lifetime", Element::create(3000));
+        EXPECT_NO_THROW(conf.sanityChecksLifetime(target, "lifetime"));
+    }
+
+    {
+        SCOPED_TRACE("min-lifetime and max-lifetime but no lifetime");
+
+        SrvConfig empty(10);
+        SrvConfig conf(32);
+        conf.addConfiguredGlobal("min-lifetime", Element::create(1000));
+        conf.addConfiguredGlobal("max-lifetime", Element::create(3000));
+        std::string msg = "have min-lifetime and max-lifetime but no ";
+        msg += "lifetime (default)";
+        EXPECT_THROW_MSG(conf.sanityChecksLifetime(empty, "lifetime"),
+                         isc::BadValue, msg);
+    }
+
+    {
+        SCOPED_TRACE("all lifetime parameters");
+
+        SrvConfig conf(32);
+        conf.addConfiguredGlobal("min-lifetime", Element::create(1000));
+        conf.addConfiguredGlobal("lifetime", Element::create(2000));
+        conf.addConfiguredGlobal("max-lifetime", Element::create(3000));
+        EXPECT_NO_THROW(conf.sanityChecksLifetime(target, "lifetime"));
+    }
+
+    {
+        SCOPED_TRACE("overwrite all lifetime parameters");
+
+        SrvConfig conf(32);
+        conf.addConfiguredGlobal("min-lifetime", Element::create(100));
+        conf.addConfiguredGlobal("lifetime", Element::create(200));
+        conf.addConfiguredGlobal("max-lifetime", Element::create(300));
+        EXPECT_NO_THROW(conf.sanityChecksLifetime(target, "lifetime"));
+    }
+
+    {
+        SCOPED_TRACE("min-lifetime > max-lifetime");
+
+        SrvConfig conf(32);
+        conf.addConfiguredGlobal("min-lifetime", Element::create(2000));
+        conf.addConfiguredGlobal("max-lifetime", Element::create(1000));
+        std::string msg = "the value of new min-lifetime (2000) is not less ";
+        msg += "than new max-lifetime (1000)";
+        EXPECT_THROW_MSG(conf.sanityChecksLifetime(target, "lifetime"),
+                         isc::BadValue, msg);
+    }
+
+    {
+        SCOPED_TRACE("target min-lifetime > max-lifetime");
+
+        SrvConfig conf(32);
+        conf.addConfiguredGlobal("max-lifetime", Element::create(500));
+        std::string msg = "the value of previous min-lifetime (1000) is not ";
+        msg += "less than new max-lifetime (500)";
+        EXPECT_THROW_MSG(conf.sanityChecksLifetime(target, "lifetime"),
+                         isc::BadValue, msg);
+    }
+
+    {
+        SCOPED_TRACE("min-lifetime > target max-lifetime");
+
+        SrvConfig conf(32);
+        conf.addConfiguredGlobal("min-lifetime", Element::create(4000));
+        std::string msg = "the value of new min-lifetime (4000) is not less ";
+        msg += "than previous max-lifetime (3000)";
+        EXPECT_THROW_MSG(conf.sanityChecksLifetime(target, "lifetime"),
+                         isc::BadValue, msg);
+    }
+
+    {
+        SCOPED_TRACE("min-lifetime > lifetime");
+
+        SrvConfig empty(10);
+        SrvConfig conf(32);
+        conf.addConfiguredGlobal("min-lifetime", Element::create(2000));
+        conf.addConfiguredGlobal("lifetime", Element::create(1000));
+        std::string msg = "the value of new min-lifetime (2000) is not less ";
+        msg += "than new (default) lifetime (1000)";
+        EXPECT_THROW_MSG(conf.sanityChecksLifetime(empty, "lifetime"),
+                         isc::BadValue, msg);
+    }
+
+    {
+        SCOPED_TRACE("target min-lifetime > lifetime");
+
+        SrvConfig conf(32);
+        SrvConfig target2(20);
+        conf.addConfiguredGlobal("lifetime", Element::create(1000));
+        target2.addConfiguredGlobal("min-lifetime", Element::create(2000));
+        std::string msg = "the value of previous min-lifetime (2000) is not ";
+        msg += "less than new (default) lifetime (1000)";
+        EXPECT_THROW_MSG(conf.sanityChecksLifetime(target2, "lifetime"),
+                         isc::BadValue, msg);
+    }
+
+    {
+        SCOPED_TRACE("min-lifetime > target lifetime");
+
+        SrvConfig conf(32);
+        SrvConfig target2(20);
+        conf.addConfiguredGlobal("min-lifetime", Element::create(2000));
+        target2.addConfiguredGlobal("lifetime", Element::create(1000));
+        std::string msg = "the value of new min-lifetime (2000) is not less ";
+        msg += "than previous (default) lifetime (1000)";
+        EXPECT_THROW_MSG(conf.sanityChecksLifetime(target2, "lifetime"),
+                         isc::BadValue, msg);
+    }
+
+    {
+        SCOPED_TRACE("lifetime > max-lifetime");
+
+        SrvConfig empty(10);
+        SrvConfig conf(32);
+        conf.addConfiguredGlobal("lifetime", Element::create(2000));
+        conf.addConfiguredGlobal("max-lifetime", Element::create(1000));
+        std::string msg = "the value of new (default) lifetime (2000) is not ";
+        msg += "less than new max-lifetime (1000)";
+        EXPECT_THROW_MSG(conf.sanityChecksLifetime(empty, "lifetime"),
+                         isc::BadValue, msg);
+    }
+
+    {
+        SCOPED_TRACE("target lifetime > max-lifetime");
+
+        SrvConfig conf(32);
+        SrvConfig target2(20);
+        conf.addConfiguredGlobal("max-lifetime", Element::create(1000));
+        target2.addConfiguredGlobal("lifetime", Element::create(2000));
+        std::string msg = "the value of previous (default) lifetime (2000) ";
+        msg += "is not less than new max-lifetime (1000)";
+        EXPECT_THROW_MSG(conf.sanityChecksLifetime(target2, "lifetime"),
+                         isc::BadValue, msg);
+    }
+
+    {
+        SCOPED_TRACE("lifetime > target max-lifetime");
+
+        SrvConfig conf(32);
+        SrvConfig target2(20);
+        conf.addConfiguredGlobal("lifetime", Element::create(2000));
+        target2.addConfiguredGlobal("max-lifetime", Element::create(1000));
+        std::string msg = "the value of new (default) lifetime (2000) is not ";
+        msg += "less than previous max-lifetime (1000)";
+        EXPECT_THROW_MSG(conf.sanityChecksLifetime(target2, "lifetime"),
+                         isc::BadValue, msg);
+    }
+
+    {
+        SCOPED_TRACE("lifetime not between min-lifetime and max-lifetime (too small)");
+
+        SrvConfig conf(32);
+        conf.addConfiguredGlobal("lifetime", Element::create(500));
+        std::string msg = "the value of new (default) lifetime (500) is not ";
+        msg += "between previous min-lifetime (1000) and ";
+        msg += "previous max-lifetime (3000)";
+        EXPECT_THROW_MSG(conf.sanityChecksLifetime(target, "lifetime"),
+                         isc::BadValue, msg);
+    }
+
+    {
+        SCOPED_TRACE("lifetime not between min-lifetime and max-lifetime (too large)");
+
+        SrvConfig conf(32);
+        conf.addConfiguredGlobal("lifetime", Element::create(4000));
+        std::string msg = "the value of new (default) lifetime (4000) is not ";
+        msg += "between previous min-lifetime (1000) and ";
+        msg += "previous max-lifetime (3000)";
+        EXPECT_THROW_MSG(conf.sanityChecksLifetime(target, "lifetime"),
+                         isc::BadValue, msg);
+    }
+
+    {
+        SCOPED_TRACE("lifetime not between min-lifetime and max-lifetime (too low)");
+
+        SrvConfig conf(32);
+        conf.addConfiguredGlobal("min-lifetime", Element::create(100));
+        conf.addConfiguredGlobal("max-lifetime", Element::create(300));
+        std::string msg = "the value of previous (default) lifetime (2000) ";
+        msg += "is not between new min-lifetime (100) and ";
+        msg += "new max-lifetime (300)";
+        EXPECT_THROW_MSG(conf.sanityChecksLifetime(target, "lifetime"),
+                         isc::BadValue, msg);
+    }
+
+    {
+        SCOPED_TRACE("lifetime not between min-lifetime and max-lifetime (too high)");
+
+        SrvConfig conf(32);
+        conf.addConfiguredGlobal("min-lifetime", Element::create(10000));
+        conf.addConfiguredGlobal("max-lifetime", Element::create(30000));
+        std::string msg = "the value of previous (default) lifetime (2000) ";
+        msg += "is not between new min-lifetime (10000) and ";
+        msg += "new max-lifetime (30000)";
+        EXPECT_THROW_MSG(conf.sanityChecksLifetime(target, "lifetime"),
+                         isc::BadValue, msg);
+    }
+}
+
 } // end of anonymous namespace
