@@ -1,18 +1,35 @@
 #!/bin/sh
 
-prefix=/usr/local
+# Copyright (C) 2020 Internet Systems Consortium, Inc. ("ISC")
+#
+# This Source Code Form is subject to the terms of the Mozilla Public
+# License, v. 2.0. If a copy of the MPL was not distributed with this
+# file, You can obtain one at http://mozilla.org/MPL/2.0/.
+
+# shellcheck disable=SC1091
+# SC1091: Not following: ... was not specified as input (see shellcheck -x).
+
+# Exit with error if commands exit with non-zero and if undefined variables are
+# used.
+set -eu
+
+# shellcheck disable=SC2034
+# SC2034: ... appears unused. Verify use (or export if used externally).
+prefix="/usr/local"
+
 # Include utilities. Use installed version if available and
 # use build version if it isn't.
 if [ -e ${prefix}/share/kea/scripts/admin-utils.sh ]; then
-    . ${prefix}/share/kea/scripts/admin-utils.sh
+    . "${prefix}/share/kea/scripts/admin-utils.sh"
 else
-    . /home/jenkins/workspace/kea-dev/tarball-internal/kea/src/bin/admin/admin-utils.sh
+    . "/home/jenkins/workspace/kea-dev/tarball-internal/kea/src/bin/admin/admin-utils.sh"
 fi
 
-VERSION=`pgsql_version "$@"`
+VERSION=$(pgsql_version "$@")
 
 if [ "$VERSION" != "6.1" ]; then
-    printf "This script upgrades 6.1 to 6.2. Reported version is $VERSION. Skipping upgrade.\n"
+    printf 'This script upgrades 6.1 to 6.2. '
+    printf 'Reported version is %s. Skipping upgrade.\n' "${VERSION}"
     exit 0
 fi
 
@@ -52,6 +69,3 @@ UPDATE schema_version
 COMMIT;
 
 EOF
-
-exit $RESULT
-
